@@ -1,7 +1,8 @@
 import os
 
+
 def delete_id():
 
-    id_file = '.dailydevid.txt'
+    id_file = ".dailydevid.txt"
     os.remove(id_file)
     print("daily.dev id successfully deleted")
